pytest\_skippy
==============

.. automodule:: pytest_skippy
    :members:
    :undoc-members:
    :show-inheritance:

pytest\_skippy\.core
--------------------

.. automodule:: pytest_skippy.core

    .. autoclass:: Skippy
        :members: should_run

pytest\_skippy\.git
-------------------

.. automodule:: pytest_skippy.git
    :members:
    :undoc-members:
    :show-inheritance:

pytest\_skippy\.imp
-------------------

.. automodule:: pytest_skippy.imp
    :members:
    :undoc-members:
    :show-inheritance:

pytest\_skippy\.parse
---------------------

.. automodule:: pytest_skippy.parse
    :members:
    :show-inheritance:
    :exclude-members: ImportVisitor

pytest\_skippy\.util
--------------------

.. automodule:: pytest_skippy.util
    :members:
    :undoc-members:
    :show-inheritance:


